pub fn mangle_headers(data: &str) -> String {
    let (header, rows) = data.split_at(data.find('\n').unwrap());
    let fields = header.trim().split(",");
    let mut modified_headers: Vec<String> = Vec::new();
    for field in fields {
        if let Some(f) = detect_field(field) {
            modified_headers.push(f.to_string());
        }
    }

    modified_headers.join(",") + "\n" + rows
}

fn detect_field(field: &str) -> Option<Field> {
    match field.trim().to_lowercase() {
        x if x.contains("source") || x.contains("src") => match x {
            _ if x.contains("plate") => Some(Field::SourcePlate),
            _ if x.contains("well") => Some(Field::SourceWell),
            _ if x.contains("format") || x.contains("fmt") => Some(Field::SourceFormat),
            _ => None,
        },
        x if x.contains("destination") || x.contains("dest") => match x {
            _ if x.contains("plate") => Some(Field::DestinationPlate),
            _ if x.contains("well") => Some(Field::DestinationWell),
            _ if x.contains("format") || x.contains("fmt") => Some(Field::DestinationFormat),
            _ => None,
        },
        x if x.contains("volume") => Some(Field::Volume),
        x if x.contains("concentration") => Some(Field::Concentration),
        _ => None,
    }
}

enum Field {
    SourcePlate,
    DestinationPlate,
    SourceWell,
    DestinationWell,
    SourceFormat,
    DestinationFormat,
    Volume,
    Concentration,
}

impl ToString for Field {
    fn to_string(&self) -> String {
        match self {
            Field::SourcePlate => "sourceplate".to_string(),
            Field::DestinationPlate => "destinationplate".to_string(),
            Field::SourceWell => "sourcewell".to_string(),
            Field::DestinationWell => "destinationwell".to_string(),
            Field::SourceFormat => "sourceformat".to_string(),
            Field::DestinationFormat => "destinationformat".to_string(),
            Field::Volume => "volume".to_string(),
            Field::Concentration => "concentration".to_string(),
        }
    }
}
